@@ -6,6 +6,7 @@ from urllib import parse
 
 import allure
 from selenium import webdriver
+from selenium.common.exceptions import NoAlertPresentException
 from selenium.webdriver import (
     ChromeOptions,
     DesiredCapabilities,
@@ -20,12 +21,12 @@ from selenium.webdriver.remote.remote_connection import LOGGER
 from webdriver_manager.firefox import GeckoDriverManager
 from webdriver_manager.microsoft import EdgeChromiumDriverManager, IEDriverManager
 
-from qrunner.core.web.element import WebElement
 from qrunner.utils.config import config
-from qrunner.utils.exceptions import ScreenFailException
+from qrunner.utils.exceptions import ScreenFailException, HostIsNull
 from qrunner.utils.log import logger
 from qrunner.utils.webdriver_manager_extend import ChromeDriverManager
 
+
 LOGGER.setLevel(logging.WARNING)
 
 
@@ -214,53 +215,71 @@ class Browser(object):
 
 
 class WebDriver(object):
-    _instance = {}
-
-    def __new__(cls, browser_name=None):
-        if browser_name not in cls._instance:
-            cls._instance[browser_name] = super().__new__(cls)
-        return cls._instance[browser_name]
 
     def __init__(self, browser_name=None):
         self.d = Browser(browser_name)
-        self.d.set_page_load_timeout(config.get_timeout())
+        timeout = config.get_timeout()
+        timeout = timeout if timeout is not None else 60
+        self.d.set_page_load_timeout(timeout)
         if ChromeConfig.headless:
             self.d.set_window_size(1920, 1080)
         else:
             self.d.maximize_window()
 
-    @classmethod
-    def get_instance(cls, browser_name=None):
-        """Create singleton"""
-        if browser_name not in cls._instance:
-            logger.info(f"[{browser_name}] Create web driver singleton")
-            return WebDriver(browser_name)
-        return WebDriver._instance[browser_name]
+    @property
+    def page_content(self):
+        logger.info('获取页面内容')
+        page_source = self.d.page_source
+        return page_source
 
-    @staticmethod
-    def get_elem(**kwargs):
-        return WebElement(**kwargs)
+    @property
+    def title(self):
+        logger.info("获取页面标题")
+        title = self.d.title
+        return title
+
+    @property
+    def url(self):
+        logger.info("获取页面url")
+        url = self.d.current_url
+        return url
+
+    @property
+    def alert_text(self):
+        logger.info("获取alert的文本")
+        try:
+            alert_text = self.d.switch_to.alert.text
+        except NoAlertPresentException:
+            logger.info(f'没有出现alert')
+            return None
+        return alert_text
+
+    def set_page_timeout(self, timeout):
+        """设置页面超时时间"""
+        self.d.set_page_load_timeout(timeout)
+
+    def set_script_time(self, timeout):
+        """设置异步脚本的超时时间"""
+        self.d.set_script_timeout(timeout)
 
     def open_url(self, url=None, login=True):
+        """访问url"""
         if url is None:
             base_url = config.get_host()
             if not base_url:
-                logger.debug("请设置base_url")
-                sys.exit()
+                raise HostIsNull('请设置base_url')
             url = base_url
         else:
             if "http" not in url:
                 base_url = config.get_host()
                 if not base_url:
-                    logger.debug("请设置base_url")
-                    sys.exit()
+                    raise HostIsNull('请设置base_url')
                 url = parse.urljoin(base_url, url)
         logger.info(f"访问: {url}")
         self.d.get(url)
         # 把默认请求头添加到cookie中
         if login:
             headers = config.get_login()
-            logger.debug(headers)
             cookies = []
             if headers:
                 for k, v in headers.items():
@@ -273,11 +292,25 @@ class WebDriver(object):
         self.d.back()
 
     def screenshot(self, file_name):
+        """截图"""
+        if "." in file_name:
+            file_name = file_name.split(r".")[0]
+        # 截图并保存到当前目录的images文件夹中
+        img_dir = os.path.join(os.getcwd(), "images")
+        if os.path.exists(img_dir) is False:
+            os.mkdir(img_dir)
+        file_path = os.path.join(img_dir, f'{file_name}.png')
+        logger.info(f'截图保存至: {file_path}')
+        self.d.save_screenshot(file_path)
+        return file_path
+
+    def screenshot_with_time(self, file_name):
         """
         截图并保存到预定路径
         @param file_name: foo.png or fool
         @return:
         """
+        logger.info(f'截图: {file_name}')
         try:
             # 把文件名处理成test.png的样式
             if "." in file_name:
@@ -286,7 +319,7 @@ class WebDriver(object):
             img_dir = os.path.join(os.getcwd(), "images")
             if os.path.exists(img_dir) is False:
                 os.mkdir(img_dir)
-            time_str = time.strftime("%Y年%m月%d日 %H时%M分%S秒")
+            time_str = time.strftime("%Y-%m-%d %H:%M:%S")
             file_path = os.path.join(img_dir, f"{time_str}-{file_name}.png")
             self.d.save_screenshot(file_path)
             # 上传allure报告
@@ -299,48 +332,6 @@ class WebDriver(object):
         except Exception as e:
             raise ScreenFailException(f"{file_name} 截图失败\n{str(e)}")
 
-    # def screenshot_and_mark(self, file_name, rect):
-    #     """给图片指定范围画上红框
-    #     rect: [x, y, width, height]
-    #     x: 左上坐标x
-    #     y：左上角坐标y
-    #     width：矩形宽度
-    #     height：矩形高度
-    #     """
-    #     # 把文件名处理成test.png的样式
-    #     if '.' in file_name:
-    #         file_name = file_name.split(r'.')[0]
-    #     # 截图并保存到当前目录的images文件夹中
-    #     img_dir = os.path.join(os.getcwd(), 'images')
-    #     if os.path.exists(img_dir) is False:
-    #         os.mkdir(img_dir)
-    #     time_str = time.strftime('%Y年%m月%d日 %H时%M分%S秒')
-    #     file_path = os.path.join(img_dir, f'{time_str}-{file_name}.png')
-    #     self.d.save_screenshot(file_path)
-    #     # 画框
-    #     ImageRecognition.mark(file_path, rect)
-    #     # 上传allure报告
-    #     allure.attach.file(file_path, attachment_type=allure.attachment_type.PNG, name=f'{file_name}.png')
-    #     return file_path
-
-    def get_page_content(self):
-        page_source = self.d.page_source
-        logger.info(f"获取页面内容: \n{page_source}")
-        return page_source
-
-    # @property
-    # def rect(self):
-    #     logger.info('获取窗口的坐标及宽高')
-    #     return self.d.get_window_position()
-
-    def max_window(self):
-        logger.info("窗口设置全屏")
-        self.d.maximize_window()
-
-    def set_window(self, width, height):
-        logger.info("设置窗口长宽")
-        self.d.set_window_size(width, height)
-
     def get_windows(self):
         logger.info(f"获取当前打开的窗口列表")
         return self.d.window_handles
@@ -348,21 +339,14 @@ class WebDriver(object):
     def switch_window(self, old_windows):
         logger.info("切换到最新的window")
         current_windows = self.d.window_handles
-        newest_window = [
-            window for window in current_windows if window not in old_windows
-        ][0]
+        newest_window = [window for window in current_windows if window not in old_windows][0]
         self.d.switch_to.window(newest_window)
 
-    def window_scroll(self, width, height):
-        logger.info(f"设置scroll bar的宽高")
-        js = "window.scrollTo({w},{h});".format(w=str(width), h=str(height))
-        self.d.execute_script(js)
-
     def switch_to_frame(self, frame_id):
         logger.info(f"切换到frame {frame_id}")
         self.d.switch_to.frame(frame_id)
 
-    def switch_to_frame_out(self):
+    def frame_out(self):
         logger.info("从frame中切出来")
         self.d.switch_to.default_content()
 
@@ -370,7 +354,7 @@ class WebDriver(object):
         logger.info(f"执行js脚本: \n{script}")
         self.d.execute_script(script, *args)
 
-    def click(self, element):
+    def click_elem(self, element):
         logger.info(f"点击元素: {element}")
         self.d.execute_script("arguments[0].click();", element)
 
@@ -383,16 +367,19 @@ class WebDriver(object):
         self.d.close()
 
     def add_cookies(self, cookies: list):
+        """添加cookie列表"""
         for cookie in cookies:
             self.d.add_cookie(cookie)
 
     def get_cookies(self):
+        """获取所有cookie"""
         logger.info("获取cookies")
         cookies = self.d.get_cookies()
         logger.info(cookies)
         return cookies
 
     def get_cookie(self, name):
+        """获取指定cookie"""
         logger.info(f"获取cookie: {name}")
         cookie = self.d.get_cookie(name)
         logger.info(cookie)
@@ -410,24 +397,6 @@ class WebDriver(object):
         logger.info(f"刷新当前页")
         self.d.refresh()
 
-    def get_title(self):
-        logger.info("获取页面标题")
-        title = self.d.title
-        logger.info(title)
-        return title
-
-    def get_url(self):
-        logger.info("获取页面url")
-        url = self.d.current_url
-        logger.info(url)
-        return url
-
-    def get_alert_text(self):
-        logger.info("获取alert的文本")
-        alert_text = self.d.switch_to.alert.text
-        logger.info(alert_text)
-        return alert_text
-
     def accept_alert(self):
         logger.info("同意确认框")
         self.d.switch_to.alert.accept()
@@ -435,3 +404,15 @@ class WebDriver(object):
     def dismiss_alert(self):
         logger.info("取消确认框")
         self.d.switch_to.alert.dismiss()
+
+
+if __name__ == '__main__':
+    driver = WebDriver('chrome')
+    driver.open_url('https://www.qizhidao.com')
+    time.sleep(5)
+    print(driver.url)
+    print(driver.title)
+    print(driver.alert_text)
+    time.sleep(3)
+    driver.quit()
+
