@@ -56,7 +56,7 @@ class DingTalk:
         allure_data = get_allure_data('allure-results')
         total = allure_data.get('total')
         passed = allure_data.get('passed')
-        fail = allure_data.get('fail')
+        fail = allure_data.get('failed')
         rate = allure_data.get('rate')
 
         color_red = 'FF0000'
