@@ -4,7 +4,7 @@ https://github.com/wolverdude/GenSON
 """
 import json
 from genson import SchemaBuilder
-from qrunner import logger
+from qrunner.utils.log import logger
 
 
 def formatting(msg):
