@@ -5,7 +5,7 @@
 import pymongo
 
 
-class BaseDB(object):
+class MongoDB(object):
     def __init__(self, ip, db_name, table_name):
         self.client = pymongo.MongoClient(f"mongodb://{ip}:27017/")
         self.db = self.client[db_name]
